@@ -11,9 +11,9 @@ except:
     # print(" -> Fonctionnement en mode émulation")
     import acquisition.emulateur_sysam_sp5 as pycan
 
-from signaux.signal_gbf import SignalGBF
-from signaux.signal_fourier import SignalFourier
-from signaux.signal_sysam import SignalSysam
+from signaux.signal_gbf import GBF
+from signaux.signal_fourier import Fourier
+from signaux.signal_sysam import Sysam
 
 import base.utiles_base as utb
 
@@ -83,15 +83,13 @@ class Sysam1Base():
 
 if __name__ == "__main__":
 
-    sysam = Sysam1Base()
-    
     liste_tmin_tmax = [0, 2e-3]
     Te = 1e-4
 
     N = 6
     liste_signaux = []
     for i in range(N):
-        liste_signaux.append(SignalGBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te))
+        liste_signaux.append(GBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te))
 
     liste_signaux[0].configurer_voie("SA1", repetition = True)
     liste_signaux[1].configurer_voie("SA2", repetition = True)
