@@ -13,9 +13,9 @@ except:
 
 
 from sysam.sysam_1_base import Sysam1Base
-from signaux.signal_gbf import SignalGBF
-from signaux.signal_fourier import SignalFourier
-from signaux.signal_sysam import SignalSysam
+from signaux.signal_gbf import GBF
+from signaux.signal_fourier import Fourier
+from signaux.signal_sysam import Sysam
 
 
 import base.utiles_base as utb
@@ -63,7 +63,7 @@ if __name__ == "__main__":
     N = 6
     liste_signaux = []
     for i in range(N):
-        liste_signaux.append(SignalGBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te))
+        liste_signaux.append(GBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te))
 
     liste_signaux[0].configurer_voie("SA1", repetition = True)
     liste_signaux[1].configurer_voie("SA2", repetition = True)
