@@ -11,9 +11,9 @@ except:
     # print(" -> Fonctionnement en mode émulation")
     import acquisition.emulateur_sysam_sp5 as pycan
 
-from signaux.signal_gbf import SignalGBF
-from signaux.signal_fourier import SignalFourier
-from signaux.signal_sysam import SignalSysam
+from signaux.signal_gbf import GBF
+from signaux.signal_fourier import Fourier
+from signaux.signal_sysam import Sysam
 
 import base.temps_base
 import base.voie_base
@@ -107,7 +107,7 @@ if __name__ == "__main__":
     N = 10
     liste_signaux = []
     for i in range(N):
-        liste_signaux.append(SignalGBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te))
+        liste_signaux.append(GBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te))
 
     # # tester acquisition non synchrone
     # liste_signaux[0].configurer_voie("EA1")
@@ -117,7 +117,7 @@ if __name__ == "__main__":
     # liste_signaux[2].configurer_trigger(0)
     # sysam = SysamSP5(liste_signaux)
 
-    # SignalGBF.tracer_signaux(liste_signaux[0:3:2])
+    # GBF.tracer_signaux(liste_signaux[0:3:2])
 
     # # tester acquisition synchrone
     # liste_signaux[0].configurer_voie("EA1")
@@ -126,7 +126,7 @@ if __name__ == "__main__":
 
     # sysam = SysamSP5(liste_signaux)
 
-    # SignalGBF.tracer_signaux(liste_signaux[0:3])
+    # GBF.tracer_signaux(liste_signaux[0:3])
 
     # tester acquisition sans entrées
     liste_signaux[0].configurer_voie("EA1")
@@ -134,4 +134,4 @@ if __name__ == "__main__":
 
     sysam = SysamSP5(liste_signaux)
 
-    SignalGBF.tracer_signaux(liste_signaux[0:2])
+    GBF.tracer_signaux(liste_signaux[0:2])
